//
//  ViewController.swift
//  Graden
//
//  Created by Roelf Sluman on 10-07-15.
//  Copyright (c) 2015 www.iosacademie.nl. All rights reserved.
//

import UIKit

class ViewController: UIViewController {

  @IBOutlet weak var vanGradenLabel: UILabel!
  @IBOutlet weak var naarGradenCelsiusLabel: UILabel!
  @IBOutlet weak var naarGradenFahrenheitLabel: UILabel!
  @IBOutlet weak var naarGradenKelvinLabel: UILabel!
  @IBOutlet weak var gradenSlider: UISlider!
  @IBOutlet weak var gradenSegmentedControl: UISegmentedControl!
  
  // Constanten en functies
  let CELSIUS = 0
  let FAHRENHEIT = 1
  let KELVIN = 2
  var bandbreedte: [Int : [Float]] = Dictionary()
  var naarGradenLabels: [Int: UILabel] = Dictionary()
  
  // Omrekenfuncties:
  func cf(graden: Float) -> Float { return graden * 1.8 + 32.0 }
  func ck(graden: Float) -> Float { return graden + 273.15 }
  func fc(graden: Float) -> Float { return (graden - 32.0) / 1.8 }
  func kc(graden: Float) -> Float { return graden - 273.15 }
  func fk(graden: Float) -> Float { return ck(fc(graden)) }
  func kf(graden: Float) -> Float { return cf(kc(graden)) }

  // Deze methode wordt aangeroepen als de viewController net van het Storyboard is geladen:
  override func viewDidLoad() {
    super.viewDidLoad()

    // Standaardwaarden opgeven:
    bandbreedte = [CELSIUS : [-273.15, 200], FAHRENHEIT : [-459.67, 392], KELVIN : [0, 437]]
    naarGradenLabels = [CELSIUS: naarGradenCelsiusLabel, FAHRENHEIT: naarGradenFahrenheitLabel, KELVIN: naarGradenKelvinLabel]
    toonResultaat()
  }

  override func didReceiveMemoryWarning() {
    super.didReceiveMemoryWarning()
    // Dispose of any resources that can be recreated.
  }

  // Deze methode wordt aangeroepen zodra de slider wordt bewogen
  // of een segmented control-optie wordt gekozen. Hier wordt alles berekend en getoond.
  @IBAction func toonResultaat() {
    let index = gradenSegmentedControl.selectedSegmentIndex

    // Kleur van 'grote' graden-label aanpassen:
    vanGradenLabel.textColor = naarGradenLabels[index]?.textColor
    gradenSlider.tintColor = vanGradenLabel.textColor

    if let bandbreedte = self.bandbreedte[index] {
      var vanGraden = round(gradenSlider.value)

      // 'Bandbreedte' en waarde van slider eventueel aanpassen:
      gradenSlider.minimumValue = Float(bandbreedte[0])
      gradenSlider.maximumValue = Float(bandbreedte[1])
      vanGraden = min(max(vanGraden, gradenSlider.minimumValue), gradenSlider.maximumValue)
      gradenSlider.value = vanGraden

      // Tekst van 'grote' graden-label eventueel aanpassen:
      vanGradenLabel.text = "\(Int(vanGraden))˚"

      // Waarde van 'grote' graden-label omrekenen naar celsius, fahrenheit en kelvin:
      let naarTemperatuurInCelsius: Int
      let naarTemperatuurInFahrenheit: Int
      let naarTemperatuurInKelvin: Int
      
      switch gradenSegmentedControl.selectedSegmentIndex {
      case FAHRENHEIT:
        naarTemperatuurInCelsius = Int(round(fc(vanGraden)))
        naarTemperatuurInFahrenheit = Int(vanGraden)
        naarTemperatuurInKelvin = Int(round(fk(vanGraden)))
        
      case KELVIN:
        naarTemperatuurInCelsius = Int(round(kc(vanGraden)))
        naarTemperatuurInFahrenheit = Int(round(kf(vanGraden)))
        naarTemperatuurInKelvin = Int(vanGraden)

      default:
        naarTemperatuurInCelsius = Int(vanGraden)
        naarTemperatuurInFahrenheit = Int(round(cf(vanGraden)))
        naarTemperatuurInKelvin = Int(round(ck(vanGraden)))
      }

      // Omgerekende waarden tonen:
      naarGradenLabels[CELSIUS]?.text = "\(naarTemperatuurInCelsius)˚"
      naarGradenLabels[FAHRENHEIT]?.text = "\(naarTemperatuurInFahrenheit)˚"
      naarGradenLabels[KELVIN]?.text = "\(naarTemperatuurInKelvin)˚"
    }
  }
}